==> insighttoolkit5_5.2.1.orig.tar.xz: InsightToolkit-5.2.1/Modules/IO/NIFTI/test/BigEndian_img.h <==
/*=========================================================================
 *
 *  Copyright NumFOCUS
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
#ifndef __BigEndian_img_h
#define __BigEndian_img_h

const unsigned char BigEndian_img[] = {
  67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 16,  0, 0,
  67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0,
  67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0,
  66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0,
  66, 160, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0,
  67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 16,  0, 0,
  67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0,
  66, 160, 0, 0, 66, 160, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0,
  65, 128, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0,
  67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 80,  0, 0,
  67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0,
  65, 128, 0, 0, 65, 128, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0,
  65, 128, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0,
  67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0,
  67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0,
  66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0,
  66, 64,  0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 67, 112, 0, 0,
  67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0,
  66, 64,  0, 0, 66, 64,  0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  66, 224, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 67, 48,  0, 0,
  67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0,
  66, 224, 0, 0, 66, 224, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  66, 224, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0,
  67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0,
  66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0,
  66, 224, 0, 0, 66, 224, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  66, 224, 0, 0
};

#endif

==> insighttoolkit5_5.4.5.orig.tar.xz: InsightToolkit-5.4.5/Modules/IO/NIFTI/test/BigEndian_img.h <==
/*=========================================================================
 *
 *  Copyright NumFOCUS
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         https://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
#ifndef BigEndian_img_h
#define BigEndian_img_h

const unsigned char BigEndian_img[] = {
  67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 16,  0, 0,
  67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0,
  67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0,
  66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0,
  66, 160, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0,
  67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 16,  0, 0,
  67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0,
  66, 160, 0, 0, 66, 160, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0,
  65, 128, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0,
  67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 67, 80,  0, 0,
  67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0,
  65, 128, 0, 0, 65, 128, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0,
  65, 128, 0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 67, 16,  0, 0, 65, 128, 0, 0, 65, 128, 0, 0, 65, 128, 0, 0,
  67, 80,  0, 0, 67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0,
  67, 80,  0, 0, 67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 80,  0, 0, 67, 80,  0, 0,
  67, 80,  0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 66, 160, 0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0,
  66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0,
  66, 64,  0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 67, 112, 0, 0,
  67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0,
  66, 64,  0, 0, 66, 64,  0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  66, 224, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 67, 48,  0, 0,
  67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0,
  66, 224, 0, 0, 66, 224, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  66, 224, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  67, 48,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0,
  67, 48,  0, 0, 67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 48,  0, 0, 67, 48,  0, 0,
  67, 48,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 66, 64,  0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0,
  66, 224, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0,
  66, 224, 0, 0, 66, 224, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 67, 112, 0, 0, 66, 224, 0, 0, 66, 224, 0, 0,
  66, 224, 0, 0
};

#endif
